# aiocapsule

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This is a minimal, single-function package containing an AIOHTTP wrapper
designed for high-throughput asynchronous HTTP requests, possibly using
HTTP proxy and basic authentication.

## Install

``` sh
pip install aiocapsule
```

## How to use

A simple call returning a JSON as a dictionary:

``` python
await send_http_request('GET', 'https://api.coingecko.com/api/v3/ping')
```

    {'gecko_says': '(V3) To the Moon!'}
